import argparse
import copy
import os
import sys
import unittest
from unittest import TestSuite, TestLoader

from HtmlTestRunner import HTMLTestRunner

from integration.partial.integration_test_utils import IntegrationTestUtils
from integration.test_suites.survey_test_suite import BaseSurveyTestSuite


class FullTestSurvey(BaseSurveyTestSuite.SurveyTestSuite):

    def set_expected_values(self):
        #  no values to set
        pass


    def setUp(self) -> None:

        self.set_expected_values()

        if IntegrationTestUtils.TEST_OUT_PATH is None or not os.path.isdir(
                IntegrationTestUtils.TEST_OUT_PATH):
            FullTestSurvey.write_temp_run_config_file()
            FullTestSurvey.run_survey_pipeline()
        else:
            print(f"output in {IntegrationTestUtils.TEST_OUT_PATH} already written, skipping rerun")


    @staticmethod
    def write_temp_run_config_file():
        default_config = IntegrationTestUtils.DEFAULT_CONFIG_FILE_PATH
        default_config_dict: dict = IntegrationTestUtils.load_json_file(default_config)
        run_dict: dict = copy.deepcopy(default_config_dict)
        run_dict['WorkspacePathout'] = IntegrationTestUtils.TEST_OUT_PATH
        run_dict['WorkspacePath'] = IntegrationTestUtils.TEST_OUT_PATH
        run_dict['Survey']['SkipServerDownload'] = False

        os.makedirs(IntegrationTestUtils.TEST_OUT_PATH)
        IntegrationTestUtils.TEMP_CONFIG_FILE_NAME = IntegrationTestUtils.TEST_OUT_PATH + "temp_config.json"
        IntegrationTestUtils.write_json_file(run_dict, IntegrationTestUtils.TEMP_CONFIG_FILE_NAME)

    @staticmethod
    def run_survey_pipeline():
        IntegrationTestUtils.run_external_pipeline(BaseSurveyTestSuite.SurveyTestSuite.SURVEY_COMPONENT_NAME,
                                                   IntegrationTestUtils.TEST_START_DATE,
                                                   IntegrationTestUtils.EMAIL_CRED_PATH)


if __name__ == '__main__':

    # _parser = IntegrationTestUtils.build_arg_parser()
    #
    # _args = _parser.parse_args()
    # _config_file: str = _args.config
    # _outdir: str = _args.outdir
    # _email_cred_path: str = _args.email_cred
    # _test_report_dir: str = _args.test_report_dir
    # _run_date_type: str = _args.run_date_type
    # _custom_run_date: str = _args.custom_run_date
    #
    # IntegrationTestUtils.DEFAULT_CONFIG_FILE_PATH = _config_file
    #
    # nowstring: str = IntegrationTestUtils.get_now_string()
    # prefix: str = "temp_survey_" + nowstring
    # # prefix: str = "temp_survey"
    # BaseSurveyTestSuite.SurveyTestSuite.TEST_OUT_PATH = _outdir + prefix + os.sep
    # IntegrationTestUtils.EMAIL_CRED_PATH = _email_cred_path
    #
    # BaseSurveyTestSuite.SurveyTestSuite.TEST_START_DATE = IntegrationTestUtils.generate_run_date(_run_date_type, _custom_run_date)
    #
    # BaseSurveyTestSuite.SurveyTestSuite.TEST_JOB_DIR = "SURVEY_" + BaseSurveyTestSuite.SurveyTestSuite.TEST_START_DATE
    #
    # # Now set the sys.argv to the unittest_args (leaving sys.argv[0] alone)
    # sys.argv[1:] = _args.unittest_args
    # tests: TestSuite = TestLoader().loadTestsFromTestCase(FullTestSurvey)
    #
    # if _test_report_dir is None:
    #     _test_report_dir = BaseSurveyTestSuite.SurveyTestSuite.TEST_JOB_DIR
    #
    # runner = HTMLTestRunner(output=_test_report_dir, combine_reports = True)
    # runner.run(tests)
    IntegrationTestUtils.run_fill_integration_test_pipeline(FullTestSurvey,
                                                            test_prefix = "survey",
                                                            processor_dir = BaseSurveyTestSuite.SurveyTestSuite.SURVEY_PROCESSOR_DIR)

